@@ -35,6 +35,7 @@ from wx.lib.pubsub import Publisher
 
 # wxBanker
 from wxbanker.menubar import BankMenuBar
+from wxbanker.brandedframe import BrandedFrame
 from wxbanker import localization, messagepanel, debug
 from wxbanker import managetab
 
@@ -129,15 +130,14 @@ class BankerPanel(wx.Panel):
             self.AddMessagePanel(mpanel)
         
         
-class BankerFrame(wx.Frame):
+class BankerFrame(BrandedFrame):
     def __init__(self, bankController, welcome):
         # Load our window settings.
         config = wx.Config.Get()
         size = config.ReadInt('SIZE_X'), config.ReadInt('SIZE_Y')
         pos = config.ReadInt('POS_X'), config.ReadInt('POS_Y')
 
-        wx.Frame.__init__(self, None, title="wxBanker", size=size, pos=pos)
-        self.SetIcon(wx.ArtProvider.GetIcon('wxART_coins'))
+        BrandedFrame.__init__(self, None, title="wxBanker", size=size, pos=pos)
 
         self.Panel = BankerPanel(self, bankController)
 
@@ -190,7 +190,7 @@ class BankerFrame(wx.Frame):
     def onFirstRun(self, message):
         welcomeMsg = _("It looks like this is your first time using wxBanker!")
         welcomeMsg += "\n\n" + _("To get started, add an account using the account control in the top left corner.")
-        welcomeMsg += " " + _("The buttons in the account control allow you to add, remove, and rename an account, respectively.")
+        welcomeMsg += " " + _("The buttons in the account control allow you to add, rename, configure, and remove an account, respectively.")
         welcomeMsg += "\n\n" + _("Once you have created an account you can add transactions to it (such as your initial balance) using the controls below the grid on the bottom right.")
         welcomeMsg += "\n\n" + _("Have fun!")
         #wx.TipWindow(self, welcomeMsg, maxLength=300)
@@ -216,7 +216,7 @@ class BankerFrame(wx.Frame):
 
 
 def init(path=None, welcome=True):
-    import wx, os, sys
+    import wx, sys
     from wxbanker import fileservice
     from wxbanker.controller import Controller
 
