@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 #    https://launchpad.net/wxbanker
-#    runtests.py: Copyright 2007-2009 Mike Rooney <mrooney@ubuntu.com>
+#    runtests.py: Copyright 2007-2010 Mike Rooney <mrooney@ubuntu.com>
 #
 #    This file is part of wxBanker.
 #
@@ -30,6 +30,10 @@ def main():
     print "DOCTESTS:", doctest.testmod(controller)
     # Run all of the unit tests.
     alltests.main()
+    
+    incomplete = testbase.INCOMPLETE_TESTS
+    if incomplete:
+        print "Incomplete tests: %i!" % incomplete
 
 if __name__ == "__main__":
     main()
